import { world, system, GameMode, BlockPermutation } from '@minecraft/server';

world.beforeEvents.worldInitialize.subscribe((initEvent) => {
initEvent.blockComponentRegistry.registerCustomComponent("tp:on_tick", { 
        onTick: event => {
            const { block, entity } = event;

                    const tpCoordinates = {
                        x: block.location.x + 14,
                        y: block.location.y - 4,
                        z: block.location.z + 19
                    };
                    block.dimension.runCommandAsync(`tp @p ${tpCoordinates.x} ${tpCoordinates.y} ${tpCoordinates.z}`);
                    block.setPermutation(BlockPermutation.resolve("minecraft:grass"));
        }
    });
initEvent.blockComponentRegistry.registerCustomComponent("store_shelf_b:on_player_interact", {
        onPlayerInteract: (event) => {
            const player = event.player;
            const block = event.block;
            const blockLocation = block.location;
            const lootState = block.permutation.getState("vb8:loot");
            const active = block.permutation.withState("vb8:loot", 1);

            if (lootState >= 2 && lootState <= 10) {
                block.setPermutation(active);

                const lootTable = `loot_blocks/store_shelf/b/loot_${lootState - 2}`;

                block.dimension.runCommandAsync(
                    `loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`
                );
            }
        }
    });
initEvent.blockComponentRegistry.registerCustomComponent("store_shelf_b:on_tick", {
    onTick: event => {
        const block = event.block;
        const random = block.permutation.withState("vb8:loot", Math.floor(Math.random()*14) + 1);
        if (block.permutation.getState("vb8:loot") === 0) {
        block.setPermutation(random);
        }
      }
  });
initEvent.blockComponentRegistry.registerCustomComponent("store_shelf_a:on_player_interact", {
        onPlayerInteract: (event) => {
            const player = event.player;
            const block = event.block;
            const blockLocation = block.location;

            const lootState = block.permutation.getState("vb8:loot");
            const active = block.permutation.withState("vb8:loot", 1);

            if (lootState >= 2 && lootState <= 12) {
                block.setPermutation(active);

                const lootTable = `loot_blocks/store_shelf/a/loot_${lootState - 2}`;

                block.dimension.runCommandAsync(
                    `loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`
                );
            }
        }
    });
initEvent.blockComponentRegistry.registerCustomComponent("store_shelf_a:on_tick", {
    onTick: event => {
        const block = event.block;
        const random = block.permutation.withState("vb8:loot", Math.floor(Math.random()*16) + 1);
        if (block.permutation.getState("vb8:loot") === 0) {
        block.setPermutation(random);
        }
      }
  });
initEvent.blockComponentRegistry.registerCustomComponent("tv:on_tick_1", {
    onTick: event => {
        const block = event.block;
       const blockLocation = block.location;
       if (block.permutation.getState("vb8:active") === 2) {
 block.dimension.playSound("block.tv.channel_1", blockLocation, { pitch: 0.9, volume: 0.7 });
      }
    }
  });
initEvent.blockComponentRegistry.registerCustomComponent("tv:on_tick_2", {
    onTick: event => {
        const block = event.block;
       const blockLocation = block.location;
       if (block.permutation.getState("vb8:active") === 3) {
 block.dimension.playSound("block.tv.channel_2", blockLocation, { pitch: 0.9, volume: 0.7 });
      }
    }
  });
initEvent.blockComponentRegistry.registerCustomComponent("tv:on_tick_3", {
    onTick: event => {
        const block = event.block;
       const blockLocation = block.location;
       if (block.permutation.getState("vb8:active") === 4) {
 block.dimension.playSound("block.tv.channel_3", blockLocation, { pitch: 0.9, volume: 0.7 });
      }
    }
  });
initEvent.blockComponentRegistry.registerCustomComponent("tv:on_player_destroy", {
    onPlayerDestroy: event => {
    const player = event.player;
      const block = event.block

        block.dimension.runCommand(`stopsound @a block.tv.channel_1`);
        block.dimension.runCommand(`stopsound @a block.tv.channel_2`);
        block.dimension.runCommand(`stopsound @a block.tv.channel_3`);
    }
  });
initEvent.blockComponentRegistry.registerCustomComponent("tv:on_player_interact", {
        onPlayerInteract: (event) => {

            const player = event.player;
            const block = event.block;
            const blockLocation = block.location;

            const disabled = block.permutation.withState("vb8:active", 1);
            const activated1 = block.permutation.withState("vb8:active", 2);
            const activated2 = block.permutation.withState("vb8:active", 3);
            const activated3 = block.permutation.withState("vb8:active", 4);

            const currentState = block.permutation.getState("vb8:active");

            switch (currentState) {
                case 0:
                case 1:
                    block.setPermutation(activated1);
                    block.dimension.playSound("block.tv.channel_1", blockLocation, { pitch: 0.9, volume: 0.7 });
                    break;

                case 2:
                    block.setPermutation(activated2);
                    block.dimension.playSound("block.tv.channel_2", blockLocation, { pitch: 0.9, volume: 0.7 });
                    block.dimension.runCommandAsync(`stopsound @a block.tv.channel_1`);
                    break;

                case 3:
                    block.setPermutation(activated3);
                    block.dimension.playSound("block.tv.channel_3", blockLocation, { pitch: 0.9, volume: 0.7 });
                    block.dimension.runCommandAsync(`stopsound @a block.tv.channel_2`);
                    break;

                case 4:
                    block.setPermutation(disabled);
                    block.dimension.runCommandAsync(`stopsound @a block.tv.channel_3`);
                    break;

                default:
                    console.warn("Estado de TV no reconocido");
            }
        }
    });
initEvent.blockComponentRegistry.registerCustomComponent("radio:on_tick", {
    onTick: event => {
        const block = event.block;
       const blockLocation = block.location;
       if (block.permutation.getState("vb8:active") === 2) {
 block.dimension.playSound("block.tv.channel_3", blockLocation, { pitch: 0.9, volume: 0.7 });
      }
    }
  });
initEvent.blockComponentRegistry.registerCustomComponent("radio:on_player_destroy", {
    onPlayerDestroy: event => {
    const player = event.player;
      const block = event.block

        block.dimension.runCommand(`stopsound @a block.tv.channel_3`);
    }
  });
initEvent.blockComponentRegistry.registerCustomComponent("radio:on_player_interact", {
        onPlayerInteract: (event) => {

            const player = event.player;
            const block = event.block;
            const blockLocation = block.location;

            const disabled = block.permutation.withState("vb8:active", 1);
            const activated = block.permutation.withState("vb8:active", 2);

            const currentState = block.permutation.getState("vb8:active");

            if (currentState === 0 || currentState === 1) {
                block.setPermutation(activated);
                block.dimension.playSound("block.tv.channel_3", blockLocation, { pitch: 0.9, volume: 0.7 });
            } else if (currentState === 2) {
                block.setPermutation(disabled);
                block.dimension.runCommandAsync(`stopsound @a block.tv.channel_3`);
            }
        }
    });
initEvent.blockComponentRegistry.registerCustomComponent("kitchen_cabinet_ab:on_player_interact", {
  onPlayerInteract: event => {
    const player = event.player;
    const block = event.block;
    const blockLocation = block.location;
    const active = block.permutation.withState("vb8:active", 1);
    const playerEquippable = player.getComponent("equippable");
    const item = playerEquippable.getEquipment("Mainhand");
    const red = block.permutation.withState("vb8:dye", 1);
    const blue = block.permutation.withState("vb8:dye", 2);
    const green = block.permutation.withState("vb8:dye", 3);
    const orange = block.permutation.withState("vb8:dye", 4);
    const pink = block.permutation.withState("vb8:dye", 5);
    const purple = block.permutation.withState("vb8:dye", 6);
    const yellow = block.permutation.withState("vb8:dye", 7);

    if (block.permutation.getState("vb8:active") === 0 && item.typeId !== 'minecraft:red_dye' && item.typeId !== 'minecraft:blue_dye' && item.typeId !== 'minecraft:green_dye' && item.typeId !== 'minecraft:orange_dye' && item.typeId !== 'minecraft:pink_dye' && item.typeId !== 'minecraft:purple_dye' && item.typeId !== 'minecraft:yellow_dye') {
      let randomInt = Math.floor(Math.random() * 10) + 1;
      const lootTable = `loot_blocks/kitchen_cabinet/loot_${10 - randomInt}`;

      block.dimension.runCommandAsync(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`);
      block.setPermutation(active);
      block.dimension.playSound("random.chestopen", blockLocation, { pitch: 0.9, volume: 0.7 });
    }

    if (item.typeId === 'minecraft:red_dye') {
      block.setPermutation(red);
    }
    if (item.typeId === 'minecraft:blue_dye') {
      block.setPermutation(blue);
    }
    if (item.typeId === 'minecraft:green_dye') {
      block.setPermutation(green);
    }
    if (item.typeId === 'minecraft:orange_dye') {
      block.setPermutation(orange);
    }
    if (item.typeId === 'minecraft:pink_dye') {
      block.setPermutation(pink);
    }
    if (item.typeId === 'minecraft:purple_dye') {
      block.setPermutation(purple);
    }
    if (item.typeId === 'minecraft:yellow_dye') {
      block.setPermutation(yellow);
    }
  }
});
initEvent.blockComponentRegistry.registerCustomComponent("wooden_box_weapons:on_player_interact", {
  onPlayerInteract: event => {
    const player = event.player;
    const block = event.block;
    const blockLocation = block.location;
    const active = block.permutation.withState("vb8:active", 1);

    if (block.permutation.getState("vb8:active") === 0) {
      let randomInt = Math.floor(Math.random() * 9) + 1;
      const lootTable = `loot_blocks/wooden_box_weapons/loot_${9 - randomInt}`;

      block.dimension.runCommandAsync(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`);
      block.setPermutation(active);
      block.dimension.playSound("random.chestopen", blockLocation, { pitch: 0.9, volume: 0.7 });
    }
  }
});
initEvent.blockComponentRegistry.registerCustomComponent("wooden_box_tools:on_player_interact", {
  onPlayerInteract: event => {
    const block = event.block;
    const blockLocation = block.location;
    const active = block.permutation.withState("vb8:active", 1);

    if (block.permutation.getState("vb8:active") === 0) {
      let randomInt = Math.floor(Math.random() * 26) + 1;
      const lootTable = `loot_blocks/wooden_box_tools/loot_${26 - randomInt}`;

      block.dimension.runCommandAsync(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`);
      block.setPermutation(active);
      block.dimension.playSound("random.chestopen", blockLocation, { pitch: 0.9, volume: 0.7 });
    }
  }
});
initEvent.blockComponentRegistry.registerCustomComponent("wooden_box_ore:on_player_interact", {
  onPlayerInteract: event => {
    const block = event.block;
    const blockLocation = block.location;
    const active = block.permutation.withState("vb8:active", 1);

    if (block.permutation.getState("vb8:active") === 0) {
      let randomInt = Math.floor(Math.random() * 10) + 1;
      const lootTable = `loot_blocks/wooden_box_ore/loot_${10 - randomInt}`;

      block.dimension.runCommandAsync(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`);
      block.setPermutation(active);
      block.dimension.playSound("random.chestopen", blockLocation, { pitch: 0.9, volume: 0.7 });
    }
  }
});
initEvent.blockComponentRegistry.registerCustomComponent("wooden_box_miscellaneous:on_player_interact", {
  onPlayerInteract: event => {
    const block = event.block;
    const blockLocation = block.location;
    const active = block.permutation.withState("vb8:active", 1);

    if (block.permutation.getState("vb8:active") === 0) {
      let randomInt = Math.floor(Math.random() * 22) + 1;
      const lootTable = `loot_blocks/wooden_box_miscellaneous/loot_${22 - randomInt}`;

      block.dimension.runCommandAsync(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`);
      block.setPermutation(active);
      block.dimension.playSound("random.chestopen", blockLocation, { pitch: 0.9, volume: 0.7 });
    }
  }
});
initEvent.blockComponentRegistry.registerCustomComponent("wooden_box_food:on_player_interact", {
  onPlayerInteract: event => {
    const block = event.block;
    const blockLocation = block.location;
    const active = block.permutation.withState("vb8:active", 1);

    if (block.permutation.getState("vb8:active") === 0) {
      let randomInt = Math.floor(Math.random() * 14) + 1;
      const lootTable = `loot_blocks/wooden_box_food/loot_${14 - randomInt}`;

      block.dimension.runCommandAsync(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`);
      block.setPermutation(active);
      block.dimension.playSound("random.chestopen", blockLocation, { pitch: 0.9, volume: 0.7 });
    }
  }
});
initEvent.blockComponentRegistry.registerCustomComponent("wooden_box_farmer:on_player_interact", {
  onPlayerInteract: event => {
    const block = event.block;
    const blockLocation = block.location;
    const active = block.permutation.withState("vb8:active", 1);

    if (block.permutation.getState("vb8:active") === 0) {
      let randomInt = Math.floor(Math.random() * 10) + 1;
      const lootTable = `loot_blocks/wooden_box_farmer/loot_${10 - randomInt}`;

      block.dimension.runCommandAsync(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`);
      block.setPermutation(active);
      block.dimension.playSound("random.chestopen", blockLocation, { pitch: 0.9, volume: 0.7 });
    }
  }
});
initEvent.blockComponentRegistry.registerCustomComponent("wooden_box_armor:on_player_interact", {
  onPlayerInteract: event => {
    const block = event.block;
    const blockLocation = block.location;
    const active = block.permutation.withState("vb8:active", 1);

    if (block.permutation.getState("vb8:active") === 0) {
      let randomInt = Math.floor(Math.random() * 25) + 1;
      const lootTable = `loot_blocks/wooden_box_armor/loot_${25 - randomInt}`;

      block.dimension.runCommandAsync(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`);
      block.setPermutation(active);
      block.dimension.playSound("random.chestopen", blockLocation, { pitch: 0.9, volume: 0.7 });
    }
  }
});
initEvent.blockComponentRegistry.registerCustomComponent("wooden_box_ammo:on_player_interact", {
  onPlayerInteract: event => {
    const block = event.block;
    const blockLocation = block.location;
    const active = block.permutation.withState("vb8:active", 1);

    if (block.permutation.getState("vb8:active") === 0) {
      let randomInt = Math.floor(Math.random() * 2) + 1;
      const lootTable = `loot_blocks/wooden_box_ammo/loot_${2 - randomInt}`;

      block.dimension.runCommandAsync(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`);
      block.setPermutation(active);
      block.dimension.playSound("random.chestopen", blockLocation, { pitch: 0.9, volume: 0.7 });
    }
  }
});
initEvent.blockComponentRegistry.registerCustomComponent("fridge:on_player_interact", {
  onPlayerInteract: event => {
    const block = event.block;
    const blockLocation = block.location;
    const active = block.permutation.withState("vb8:active", 1);

    if (block.permutation.getState("vb8:active") === 0) {
      let randomInt = Math.floor(Math.random() * 14) + 1;
      const lootTable = `loot_blocks/fridge/loot_${14 - randomInt}`;

      block.dimension.runCommandAsync(`loot spawn ${blockLocation.x} ${blockLocation.y} ${blockLocation.z} loot "${lootTable}"`);
      block.setPermutation(active);
      block.dimension.playSound("random.chestopen", blockLocation, { pitch: 0.9, volume: 0.7 });
    }
  }
});
initEvent.blockComponentRegistry.registerCustomComponent("cans:on_tick", {
    onTick: event => {
        const block = event.block;
        const random = block.permutation.withState("vb8:loot", Math.floor(Math.random()*15) + 1);
        if (block.permutation.getState("vb8:loot") === 0) {
        block.setPermutation(random);
        }
      }
  });
initEvent.blockComponentRegistry.registerCustomComponent("kitchen_cabinet:on_player_interact", {
    onPlayerInteract: event => {
    const player = event.player;
      const block = event.block;
     const playerEquippable = player.getComponent("equippable");
      const item = playerEquippable.getEquipment("Mainhand");
     const red = block.permutation.withState("vb8:dye", 1);
     const blue = block.permutation.withState("vb8:dye", 2);
     const green = block.permutation.withState("vb8:dye", 3);

       const orange = block.permutation.withState("vb8:dye", 4);
      const pink = block.permutation.withState("vb8:dye", 5);
      const purple = block.permutation.withState("vb8:dye", 6);
      const yellow = block.permutation.withState("vb8:dye", 7);

       if (item.typeId === 'minecraft:red_dye') {
        block.setPermutation(red);
      }
      if (item.typeId === 'minecraft:blue_dye') {
        block.setPermutation(blue);
      }
      if (item.typeId === 'minecraft:green_dye') {
        block.setPermutation(green);
      }
      if (item.typeId === 'minecraft:orange_dye') {
        block.setPermutation(orange);
      }
      if (item.typeId === 'minecraft:pink_dye') {
        block.setPermutation(pink);
      }
      if (item.typeId === 'minecraft:purple_dye') {
        block.setPermutation(purple);
      }
     if (item.typeId === 'minecraft:yellow_dye') {
        block.setPermutation(yellow);
      }
    }
  });
initEvent.blockComponentRegistry.registerCustomComponent('chair:on_player_interact', {
        onPlayerInteract: event => {
            const { block, player } = event;
            const equipment = player.getComponent('equippable');
            const selectedItem = equipment.getEquipment('Mainhand');

            block.dimension.runCommandAsync(`summon vb8:chair ${block.location.x} ${block.location.y + 0.6} ${block.location.z}`);
        }
    });
});
